---
name: "\U0001F4F0 Custom Issue"
about: Submit a generic issue to help us improve nc-time-axis
title: ''
labels: 'New: Issue'
assignees: ''

---

## 📰 Custom Issue
<!-- Provide a clear description of what the issue is, and we'll try our best to help 😀 -->
